@@ -6,22 +6,6 @@ from contextlib import redirect_stderr
 
 import pydevd_pycharm
 import waiting
-from importlib.util import find_spec
-
-
-class Options(object):
-    mode = None
-    address = None
-    log_to = None
-    log_to_stderr = False
-    target = None  # unicode
-    target_kind = None
-    wait_for_client = False
-    adapter_access_token = None
-
-
-options = Options()
-options.config = {"qt": "none", "subProcess": True}
 
 
 class PycharmRemoteDebugger:
